@@ -82,7 +82,7 @@
  *             - Allow full filter specifications in -f
  */
 
-#include "config.h"
+#include "squid.h"
 
 #define LDAP_DEPRECATED 1
 
@@ -93,7 +93,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#ifdef _SQUID_MSWIN_		/* Native Windows port and MinGW */
+#if _SQUID_MSWIN_		/* Native Windows port and MinGW */
 
 #define snprintf _snprintf
 #include <windows.h>
@@ -554,7 +554,7 @@ main(int argc, char **argv)
     /* On Windows ldap_start_tls_s is available starting from Windows XP,
      * so we need to bind at run-time with the function entry point
      */
-#ifdef _SQUID_MSWIN_
+#if _SQUID_MSWIN_
     if (use_tls) {
 
         HMODULE WLDAP32Handle;
@@ -623,15 +623,19 @@ ldap_escape_value(char *escaped, int size, const char *src)
             n += 3;
             size -= 3;
             if (size > 0) {
-                *escaped++ = '\\';
-                snprintf(escaped, 3, "%02x", (unsigned char) *src++);
+                *escaped = '\\';
+                ++escaped;
+                snprintf(escaped, 3, "%02x", (unsigned char) *src);
+                ++src;
                 escaped += 2;
             }
             break;
         default:
-            *escaped++ = *src++;
-            n++;
-            size--;
+            *escaped = *src;
+            ++escaped;
+            ++src;
+            ++n;
+            --size;
         }
     }
     *escaped = '\0';
