@@ -32,10 +32,8 @@
  *
  */
 
-#ifndef _SQUID_REFCOUNT_H_
-#define _SQUID_REFCOUNT_H_
-
-#include "config.h"
+#ifndef SQUID_REFCOUNT_H_
+#define SQUID_REFCOUNT_H_
 
 #if HAVE_IOSTREAM
 #include <iostream>
@@ -69,13 +67,9 @@ public:
 
     bool operator !() const { return !p_; }
 
-    C const * operator-> () const {return p_; }
+    C * operator-> () const {return const_cast<C *>(p_); }
 
-    C * operator-> () {return const_cast<C *>(p_); }
-
-    C const & operator * () const {return *p_; }
-
-    C & operator * () {return *const_cast<C *>(p_); }
+    C & operator * () const {return *const_cast<C *>(p_); }
 
     C const * getRaw() const {return p_; }
 
@@ -150,4 +144,4 @@ inline std::ostream &operator <<(std::ostream &os, const RefCount<C> &p)
         return os << "NULL";
 }
 
-#endif /* _SQUID_REFCOUNT_H_ */
+#endif /* SQUID_REFCOUNT_H_ */
