@@ -34,6 +34,7 @@
 #ifndef SQUID_HTTPHIERARCHYLOGENTRY_H
 #define SQUID_HTTPHIERARCHYLOGENTRY_H
 
+#include "comm/Connection.h"
 #include "hier_code.h"
 #include "lookup_t.h"
 #include "rfc2181.h"
@@ -47,6 +48,13 @@ class HierarchyLogEntry
 
 public:
     HierarchyLogEntry();
+    ~HierarchyLogEntry() { tcpServer = NULL; };
+
+    /// Record details from a new server connection.
+    /// call this whenever the destination server changes.
+    void note(const Comm::ConnectionPointer &server, const char *requestedHost);
+
+public:
     hier_code code;
     char host[SQUIDHOSTNAMELEN];
     ping_data ping;
@@ -64,9 +72,8 @@ public:
     int64_t peer_response_time; ///< last peer response delay
     timeval first_conn_start; ///< first connection use among all peers
     int64_t total_response_time; ///< cumulative for all peers
-    u_short peer_local_port; //< local port of the last server-side connection
+    Comm::ConnectionPointer tcpServer; ///< TCP/IP level details of the last server-side connection
+    int64_t bodyBytesRead;  ///< number of body bytes received from the next hop or -1
 };
 
-extern void hierarchyNote(HierarchyLogEntry *, hier_code, const char *);
-
 #endif /* SQUID_HTTPHIERARCHYLOGENTRY_H */
