@@ -136,12 +136,14 @@ HttpHdrSc::parse(const String * str)
         if ((p = strchr(item, '=')) && (p - item < ilen)) {
             vlen = ilen - (p + 1 - item);
             ilen = p - item;
-            p++;
+            ++p;
         }
 
         /* decrease ilen to still match the token for ';' qualified non '=' statments */
-        else if ((p = strchr(item, ';')) && (p - item < ilen))
-            ilen = p++ - item;
+        else if ((p = strchr(item, ';')) && (p - item < ilen)) {
+            ilen = p - item;
+            ++p;
+        }
 
         /* find type */
         /* TODO: use a type-safe map-based lookup */
@@ -175,7 +177,7 @@ HttpHdrSc::parse(const String * str)
             if (type != SC_OTHER)
                 debugs(90, 2, "hdr sc: ignoring duplicate control-directive: near '" << item << "' in '" << str << "'");
 
-            ScFieldsInfo[type].stat.repCount++;
+            ++ ScFieldsInfo[type].stat.repCount;
 
             continue;
         }
@@ -194,22 +196,23 @@ HttpHdrSc::parse(const String * str)
             int ma;
             if (p && httpHeaderParseInt(p, &ma)) {
                 sct->maxAge(ma);
+
+                if ((p = strchr (p, '+'))) {
+                    int ms;
+                    ++p; //skip the + char
+                    if (httpHeaderParseInt(p, &ms)) {
+                        sct->maxStale(ms);
+                    } else {
+                        debugs(90, 2, "sc: invalid max-stale specs near '" << item << "'");
+                        sct->clearMaxStale();
+                        /* leave the max-age alone */
+                    }
+                }
             } else {
                 debugs(90, 2, "sc: invalid max-age specs near '" << item << "'");
                 sct->clearMaxAge();
             }
 
-            if ((p = strchr (p, '+'))) {
-                int ms;
-                ++p; //skip the + char
-                if (httpHeaderParseInt(p, &ms)) {
-                    sct->maxStale(ms);
-                } else {
-                    debugs(90, 2, "sc: invalid max-stale specs near '" << item << "'");
-                    sct->clearMaxStale();
-                    /* leave the max-age alone */
-                }
-            }
             break;
         }
 
@@ -280,7 +283,7 @@ HttpHdrScTarget::packInto(Packer * p) const
             if (flag == SC_CONTENT)
                 packerPrintf(p, "=\"" SQUIDSTRINGPH "\"", SQUIDSTRINGPRINT(content_));
 
-            pcount++;
+            ++pcount;
         }
     }
 
