@@ -85,7 +85,7 @@ int64_t
 GetInteger64(void)
 {
     char *token = strtok(NULL, w_space);
-    int i;
+    int64_t i;
 
     if (token == NULL)
         self_destruct();
@@ -179,7 +179,8 @@ GetHostWithPort(char *token, Ip::Address *ipa)
         t = strchr(host, ']');
         if (!t)
             return false;
-        *t++ = '\0';
+        *t = '\0';
+        ++t;
         if (*t != ':')
             return false;
         port = xatos(t + 1);
