@@ -38,7 +38,7 @@
  *
  */
 
-#include "squid.h"
+#include "squid-old.h"
 #include "acl/Acl.h"
 #include "acl/Checklist.h"
 #include "acl/Strategised.h"
@@ -196,7 +196,7 @@ aclParseAccessLine(ConfigParser &parser, acl_access ** head)
     for (B = *head, T = head; B; T = &B->next, B = B->next);
     *T = A;
 
-    /* We lock _acl_access structures in ACLChecklist::check() */
+    /* We lock _acl_access structures in ACLChecklist::matchNonBlocking() */
 }
 
 void
@@ -217,11 +217,11 @@ aclParseAclList(ConfigParser &parser, ACLList ** head)
             t++;
         }
 
-        debugs(28, 3, "aclParseAccessLine: looking for ACL name '" << t << "'");
+        debugs(28, 3, "aclParseAclList: looking for ACL name '" << t << "'");
         a = ACL::FindByName(t);
 
         if (a == NULL) {
-            debugs(28, 0, "aclParseAccessLine: ACL name '" << t << "' not found.");
+            debugs(28, 0, "aclParseAclList: ACL name '" << t << "' not found.");
             delete L;
             parser.destruct();
             continue;
@@ -309,37 +309,3 @@ aclDestroyDenyInfoList(acl_deny_info_list ** list)
 
     *list = NULL;
 }
-
-/*
- * This function traverses all ACL elements referenced
- * by an access list (presumably 'http_access').   If
- * it finds a PURGE method ACL, then it returns TRUE,
- * otherwise FALSE.
- */
-/* XXX: refactor this more sensibly. perhaps have the parser detect it ? */
-int
-aclPurgeMethodInUse(acl_access * a)
-{
-    ACLList *b;
-
-    debugs(28, 6, "aclPurgeMethodInUse: invoked for '" << a->cfgline << "'");
-
-    for (; a; a = a->next) {
-        for (b = a->aclList; b; b = b->next) {
-            ACLStrategised<HttpRequestMethod> *tempAcl = dynamic_cast<ACLStrategised<HttpRequestMethod> *>(b->_acl);
-
-            if (!tempAcl) {
-                debugs(28, 7, "aclPurgeMethodInUse: can't create tempAcl");
-                continue;
-            }
-
-            if (tempAcl->match(METHOD_PURGE)) {
-                debugs(28, 6, "aclPurgeMethodInUse: returning true");
-                return true;
-            }
-        }
-    }
-
-    debugs(28, 6, "aclPurgeMethodInUse: returning false");
-    return false;
-}
