@@ -2,7 +2,7 @@
  * DEBUG: section 93    ICAP (RFC 3507) Client
  */
 
-#include "squid.h"
+#include "squid-old.h"
 #include "adaptation/Answer.h"
 #include "adaptation/icap/Config.h"
 #include "adaptation/icap/ModXact.h"
@@ -115,7 +115,7 @@ Adaptation::Icap::ServiceRep::getConnection(bool retriableXact, bool &reused)
 }
 
 // pools connection if it is reusable or closes it
-void Adaptation::Icap::ServiceRep::putConnection(const Comm::ConnectionPointer &conn, bool isReusable, const char *comment)
+void Adaptation::Icap::ServiceRep::putConnection(const Comm::ConnectionPointer &conn, bool isReusable, bool sendReset, const char *comment)
 {
     Must(Comm::IsConnOpen(conn));
     // do not pool an idle connection if we owe connections
@@ -124,9 +124,14 @@ void Adaptation::Icap::ServiceRep::putConnection(const Comm::ConnectionPointer &
         commUnsetConnTimeout(conn);
         theIdleConns->push(conn);
     } else {
-        debugs(93, 3, HERE << "closing pconn" << comment);
-        // comm_close will clear timeout
-        conn->close();
+        debugs(93, 3, HERE << (sendReset ? "RST" : "FIN") << "-closing " <<
+               comment);
+        // comm_close called from Connection::close will clear timeout
+        // TODO: add "bool sendReset = false" to Connection::close()?
+        if (sendReset)
+            comm_reset_close(conn);
+        else
+            conn->close();
     }
 
     Must(theBusyConns > 0);
@@ -204,7 +209,7 @@ int Adaptation::Icap::ServiceRep::excessConnections() const
 
 void Adaptation::Icap::ServiceRep::noteGoneWaiter()
 {
-    theAllWaiters--;
+    --theAllWaiters;
 
     // in case the notified transaction did not take the connection slot
     busyCheckpoint();
