@@ -1,6 +1,6 @@
 
 /*
- * $Id: event.h,v 1.4 2008/02/12 23:27:42 rousskov Exp $
+ * $Id$
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -34,7 +34,7 @@
 #ifndef SQUID_EVENT_H
 #define SQUID_EVENT_H
 
-#include "squid.h"
+#include "squid-old.h"
 #include "Array.h"
 #include "AsyncEngine.h"
 
