@@ -33,7 +33,7 @@
 #include "comm.h"
 #include "ip/Address.h"
 
-#if DELAY_POOLS
+#if USE_DELAY_POOLS
 class ClientInfo;
 #endif
 class PconnPool;
@@ -57,7 +57,7 @@ public:
 
 public:
     unsigned int type;
-    u_short remote_port;
+    unsigned short remote_port;
 
     Ip::Address local_addr;
     tos_t tosToServer;          /**< The TOS value for packets going towards the server.
@@ -92,7 +92,7 @@ public:
         PconnPool *pool;
     } pconn;
 
-#if DELAY_POOLS
+#if USE_DELAY_POOLS
     ClientInfo * clientInfo;/* pointer to client info used in client write limiter or NULL if not present */
 #endif
     unsigned epoll_state;
@@ -113,8 +113,9 @@ public:
     WRITE_HANDLER *write_method;
 #if USE_SSL
     SSL *ssl;
+    SSL_CTX *dynamicSslContext; ///< cached and then freed when fd is closed
 #endif
-#ifdef _SQUID_MSWIN_
+#if _SQUID_MSWIN_
     struct {
         long handle;
     } win32;
@@ -146,7 +147,7 @@ private:
         bytes_written = 0;
         pconn.uses = 0;
         pconn.pool = NULL;
-#if DELAY_POOLS
+#if USE_DELAY_POOLS
         clientInfo = NULL;
 #endif
         epoll_state = 0;
@@ -166,8 +167,9 @@ private:
         write_method = NULL;
 #if USE_SSL
         ssl = NULL;
+        dynamicSslContext = NULL;
 #endif
-#ifdef _SQUID_MSWIN_
+#if _SQUID_MSWIN_
         win32.handle = NULL;
 #endif
         tosFromServer = '\0';
