@@ -107,7 +107,7 @@ MemObject::~MemObject()
 }
 
 int
-MemObject::mostBytesWanted(int max) const
+MemObject::mostBytesWanted(int max, bool ignoreDelayPools) const
 {
     fatal ("Not implemented");
     return -1;
