@@ -1,5 +1,5 @@
 #define SQUID_UNIT_TEST 1
-#include "config.h"
+#include "squid.h"
 #include <cppunit/TestAssert.h>
 
 #include "testHttpReply.h"
@@ -12,19 +12,6 @@ struct SquidConfig Config;
 
 /* stub functions to link successfully */
 
-#include "Store.h"
-void
-StoreEntry::timestampsSet()
-{
-    fatal("StoreEntry::timestampsSet. Not implemented.");
-}
-
-void
-StoreEntry::setPublicKey()
-{
-    fatal("StoreEntry::setPulicKey. Not implemented.");
-}
-
 #include "MemObject.h"
 int64_t
 MemObject::endOffset() const
